---
title: '[2024년04월]개인정보처리방침 개정 변경 안내'
category: 공지사항
tags:
  - 공지사항
datetime: 2024-04-09T06:47:10.391Z
---

안녕하세요\~! 포트원 입니다.

항상 포트원을 이용해주시는 고객 여러분께 진심으로 감사드립니다.

2024년 04월 12일 아래와 같이 개인정보처리방침이 변경됨을 사전 안내 드립니다.

- 공지일 : 2024.04.05(금)
- 시행일 : 2024.04.12(금)

<Highlight text="변경 및 추가내용" />

<Accordion title="▶ 개인정보의 처리목적 (변경)" content="<>

</>" image="https://help.portone.io/uploads/포트원소식/개인정보 1.png" />

<Accordion title="▶ 개인정보의 전달 (변경)" image="https://help.portone.io/uploads/포트원소식/개인정보 2.png" />

<Accordion title="▶ 수집하는 개인정보의 항목 (추가) " image="https://help.portone.io/uploads/개인정보 3.png" />

<Accordion title="▶ 개인정보의 제 3자 제공 (변경)" image="https://help.portone.io/uploads/개인정보 4.png" />

<Accordion title="▶ 개인정보 처리의 위탁 / 국외 이전 (변경)" image="https://help.portone.io/uploads/포트원소식/개인정보 5.png" />

<Accordion title="▶ 개인정보의 처리 및 보유기간 (변경)" image="https://help.portone.io/uploads/포트원소식/개인정보 6.png" />

<Accordion title="▶ 개인정보의 파기에 관한 사항 (변경)" image="https://help.portone.io/uploads/포트원소식/개인정보 7.png" />

<Accordion title="▶ 개인정보 자동 수집 장치의 설치, 운영 및 그 거부에 관한 사항 (변경)" image="https://help.portone.io/uploads/포트원소식/개인정보 8.png" />

<Accordion title="▶ 개인정보 보호를 위한 기술적/ 관리적 보호대책  (변경)" image="https://help.portone.io/uploads/포트원소식/개인정보 9.png" />

<Accordion title="▶ 개인정보 보호 전담부서 (변경)" image="https://help.portone.io/uploads/포트원소식/개인정보 10.png" />
